///////////////
// IanniX
///////////////

////////////////////////////
// NxTypes.h
////////////////////////////

#ifndef NXTYPES_H
#define NXTYPES_H

/////////////////////////////////////////////////////////
// IANNIX DATA STRUCTURES
/////////////////////////////////////////////////////////

#include <QtGui>

////////////////// 
// NxPoint 
//////////////////
typedef struct
{
	int ID;
  	float x;
  	float y;
  	float z;
}
NxPoint;

//////////////
// Color
//////////////
typedef struct
{
	int ID ;
	QColor c ;
}
Color;

////////////////
// NxEnv
////////////////
typedef struct
{
	////////////////////// GENERAL
	QString xmlVersion ;
  	QString name ;
  	QString path ;
  	int ID;
  	int groupID;
  	int length;
  	int height;
  	int nbCurves;
  	int nbTrajects;
  	int nbTriggers;
  	int nbCursors;
  	int nbComm; // Comments
  	QStringList comments;
  	////////////////////// MODES
  	bool	visualMode ;
	bool	oscOutMode ;
	bool	oscInMode ;
	bool 	showTrajects ;
	bool 	showCursors ;
	bool 	showCurves ;
	bool 	showTriggers ;
	////////////////////// OBJECTS DEFAULT VALUES
	int		defaultSpatialPeriod ;
	int		OSCTriggersDefaultIntValue ;
	float	mappingDefaultMin ;
	float	mappingDefaultMax ;
	////////////////////// FPS
	int		displayStep ;
	int		schedulerStep ;
	////////////////////// DISPLAY
	Color backColor ;
	Color scoreColor ;
	Color gridColor ;
	float 	zoom ;				// zoom value (TO XMLize)
	NxPoint center ;			// center of score view (TO XMLize)
	bool 	showGrid ;			// grid display
	bool 	crossesDraw ;		// center crosses
	bool 	scoreDraw ;			// score rectangle
	bool 	displayOn ;			// on screen infos
	bool 	circlesDraw ;		// curves circles 
	bool 	rectDraw ;			// curves rectangles
	bool 	snapGrid ;			// snap to grid
	bool 	autoGridStep ;		// auto grid step
	float 	gridStep ;			// grid step value
	bool 	showCursorsArea ;	// cursors impact areas
	////////////////////// TIME
	bool	useCirclesAlgo ;
	bool	moveCursors ;	// (TO XMLize)
	float	globalTempo ;
	float	initialTime ;
	float	finalTime ;
  	/////////////////////// NETWORK
	bool	broadcastMode ;
	bool	sendIFmessages ;
	QString UDPhost ;
	int		UDPout ;
  	int		UDPin ;
	QString		OSCCurvesDefaultMFormat ;
	QString		OSCTriggersDefaultMFormat ;
	//// Values to send
	bool	scCID, scCGID, scID, scGID, scA, scV ;
	bool	stCID, stCGID, stID, stGID, stV ;
	QString		OSCConfigMessageIP ;
	
}
NxEnv;

/////////////////////////////
// Bounding Box
/////////////////////////////
typedef struct
{
	NxPoint p1;
  	NxPoint p2;
} 
BBox;

//////////////
// Circle
//////////////
typedef struct
{
	float radius;
  	NxPoint p;
}
Circle;

/////////////
// State 
/////////////
typedef struct
{
	int type;	
	float duration;
	float frequency;
  	float coeff;
  	float scale;
}
State;

///////////////////////
// Scheduler OSC Messages
///////////////////////
typedef struct {
	QString host ;
	int port ;
	int cursGID ;
	int cursID ;
	int GID ;
	int ID ;
	int val ;
}
triggerOSC ;

typedef struct {
	QString host ;
	int port ;
	int cursGID ;
	int cursID ;
	int GID ;
	int ID ;
	float angle ;
	float val ;
}
curveOSC ;

///////////////////////////////////////////////////
// Integer Aliases for Objects
///////////////////////////////////////////////////
enum { Curve = 0, Trajectory = 1, Cursor = 2, Trigger = 3 };
enum { Both = 4, Horizontal = 5, Vertical = 6 };
enum { SplineStrip = 7, LineStrip = 8 };

//////////////////////
// Constants
//////////////////////
#define	PI 3.14159265358979323846
#endif

