///////////////
// IanniX
///////////////

////////////////////////////
// NxParser.h
////////////////////////////

#ifndef NXPARSER_H
#define NXPARSER_H

// Qt
#include <QtGui>
#include <QtXml>

// IanniX classes
#include "../base/atoms/NxTypes.h"
#include "../base/atoms/NxObject.h"
 
class NxParser : public QObject
{
	Q_OBJECT
public:
	NxParser(QString inFile);
	void read(QIODevice *file);
	
	QMap<int, NxCurve*> 	parseCurves();
	QMap<int, NxTraject*> 	parseTrajects();
	QMap<int, NxCursor*> 	parseCursors();
	QMap<int, NxTrigger*> 	parseTriggers();
	NxEnv parseEnv();
	
	// Sub Functions
  	State* 				parseTimeLine( const QDomElement&, char* inStr, int* index );
  	QVector<NxPoint>	parsePoints( const QDomElement& );
  	QList<Color> 		parseColors( const QDomElement& );
  	QList<int>			parseCursorID( const QDomElement&, int inNbCursors );
  	void 				parseSubCurves( const QDomElement&, int inCpt );
  	void 				parseLights( const QDomElement& );
  	int 				parseShape( const QDomElement& );
  	float 				parseFactor( const QDomElement& );
	Circle 				parseCircle( const QDomElement& );	
		
private:		
	QMap<int, NxCurve*> 	curves;
	QMap<int, NxTraject*> 	trajects;
	QMap<int, NxCursor*> 	cursors;
	QMap<int, NxTrigger*> 	triggers;
	NxEnv env;

	// Qt XML Objects
	QDomDocument document;
	
};

#endif

